[−][src]Struct rust_bert::albert::AlbertForMultipleChoice
ALBERT for multiple choices
Multiple choices model using a ALBERT base model and a linear classifier.
Input should be in the form [CLS] Context [SEP] Possible choice [SEP]. The choice is made along the batch axis,
assuming all elements of the batch are alternatives to be chosen from for a given context.
It is made of the following blocks:
albert: Base AlbertModeldropout: Dropout for hidden states outputclassifier: Linear layer for multiple choices
Implementations
impl AlbertForMultipleChoice[src]
pub fn new<'p, P>(p: P, config: &AlbertConfig) -> AlbertForMultipleChoice where
P: Borrow<Path<'p>>, [src]
P: Borrow<Path<'p>>,
Build a new AlbertForMultipleChoice
Arguments
p- Variable store path for the root of the ALBERT modelconfig-AlbertConfigobject defining the model architecture and decoder status
Example
use rust_bert::albert::{AlbertConfig, AlbertForMultipleChoice}; use rust_bert::Config; use std::path::Path; use tch::{nn, Device}; let config_path = Path::new("path/to/config.json"); let device = Device::Cpu; let p = nn::VarStore::new(device); let config = AlbertConfig::from_file(config_path); let albert: AlbertForMultipleChoice = AlbertForMultipleChoice::new(&p.root(), &config);
pub fn forward_t(
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
token_type_ids: Option<Tensor>,
position_ids: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Vec<Tensor>>>), &'static str>[src]
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
token_type_ids: Option<Tensor>,
position_ids: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Vec<Tensor>>>), &'static str>
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. [SEP]) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
output-Tensorof shape (1, batch size) containing the logits for each of the alternatives givenhidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)attentions-Option<Vec<Vec<Tensor>>>of length num_hidden_layers of nested length inner_group_num with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::albert::{AlbertConfig, AlbertForMultipleChoice}; let (batch_size, sequence_length) = (64, 128); let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device)); let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device)); let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device)); let position_ids = Tensor::arange(sequence_length, (Int64, device)).expand(&[batch_size, sequence_length], true); let (output, all_hidden_states, all_attentions) = no_grad(|| { albert_model .forward_t(Some(input_tensor), Some(mask), Some(token_type_ids), Some(position_ids), None, false).unwrap() });