Struct rust_bert::bart::BartForConditionalGeneration [−][src]
pub struct BartForConditionalGeneration { /* fields omitted */ }Expand description
BART Model for conditional generation
BART model with a vocabulary decoding head It is made of the following blocks:
base_model:BartModelBase BART modellinear: Linear layer without bias tied to the weights of the token id embeddings
Implementations
pub fn new<'p, P>(p: P, config: &BartConfig) -> BartForConditionalGeneration where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &BartConfig) -> BartForConditionalGeneration where
P: Borrow<Path<'p>>,
Build a new BartForConditionalGeneration
Arguments
p- Variable store path for the root of the BART modelconfig-BartConfigobject defining the model architecture
Example
use rust_bert::bart::{BartConfig, BartForConditionalGeneration};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = BartConfig::from_file(config_path);
let bart: BartForConditionalGeneration =
BartForConditionalGeneration::new(&p.root() / "bart", &config);pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_output: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> BartModelOutput
pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_output: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> BartModelOutput
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, source_sequence_length). Must be provided when not running in generation modeattention_mask- Optional attention mask of shape (batch size, source_sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.encoder_outputs- Optional tuple made of a tensor of shape (batch size, source_sequence_length, encoder_hidden_dim) and optional vectors of tensors of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size). These correspond to the encoder last hidden state and optional hidden states/attention weights for encoder layers. When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). Must be provided when running in generation mode (e.g. initialized with a BOS token)decoder_attention_mask- Optional attention mask of shape (batch size, target_sequence_length) for the decoder positions. Positions with a mask with value 0 will be masked.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
BartModelOutputcontaining:decoder_output-Tensorof shape (batch size, target_sequence_length, vocab_size) representing the logits for each vocabulary item and positionencoder_hidden_states-Tensorof shape (batch size, source_sequence_length, hidden_size) representing the activations of the last encoder hidden statecache-(Option<Tensor>, Option<Vec<&LayerState, &LayerState>>)of length n_layer containing the encoder padding mask and past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.all_encoder_hidden_states-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_encoder_attentions-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_decoder_hidden_states-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)all_decoder_attentions-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)
Example
use rust_bert::bart::{BartConfig, BartForConditionalGeneration};
let (batch_size, source_sequence_length, target_sequence_length) = (64, 128, 56);
let input_tensor = Tensor::rand(&[batch_size, source_sequence_length], (Int64, device));
let target_tensor = Tensor::rand(&[batch_size, target_sequence_length], (Int64, device));
let encoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let decoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let model_output = no_grad(|| {
bart_model
.forward_t(Some(&input_tensor),
Some(&encoder_attention_mask),
None,
Some(&target_tensor),
Some(&decoder_attention_mask),
None,
false)
});Trait Implementations
fn forward_t(
&self,
input_ids: Option<&Tensor>,
cache: Cache,
attention_mask: Option<&Tensor>,
_token_type_ids: Option<&Tensor>,
_position_ids: Option<&Tensor>,
_input_embeds: Option<&Tensor>,
encoder_outputs: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
train: bool
) -> Result<LMModelOutput, RustBertError>
fn forward_t(
&self,
input_ids: Option<&Tensor>,
cache: Cache,
attention_mask: Option<&Tensor>,
_token_type_ids: Option<&Tensor>,
_position_ids: Option<&Tensor>,
_input_embeds: Option<&Tensor>,
encoder_outputs: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
train: bool
) -> Result<LMModelOutput, RustBertError>
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)layer_past- Optional vector of lengthnum_layerscontaining tuples of optionalLayerStatescontaining the last calculated key and value pairs for the decoder. This avoids recomputing attention weights at past positions and speeds up decoding.attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Unused for BARTtoken_type_ids- Unused for BARTposition_ids- Unused for BARTencoder_outputs- Optional tensor of shape (batch size, source_sequence_length, hidden_size). When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). Must be provided when running in generation mode (e.g. initialized with a BOS token)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
LMModelOutputcontaining:lm_logits-Tensorof shape (batch size, sequence_length, vocab_size) representing the logits for each vocab item and positioncache-BartCachemade ofOption<Vec<(Option<Vec<&LayerState, &LayerState>>)>>of length n_layer containing the encoder past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.
Example
use rust_bert::pipelines::generation_utils::LMHeadModel;
use rust_bert::bart::{BartForConditionalGeneration, BartConfig};
let (batch_size, source_sequence_length, target_sequence_length) = (64, 128, 56);
let input_tensor = Tensor::rand(&[batch_size, source_sequence_length], (Int64, device));
let target_tensor = Tensor::rand(&[batch_size, target_sequence_length], (Int64, device));
let encoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let decoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let model_output = no_grad(|| {
bart_model
.forward_t(Some(&input_tensor),
Some(&encoder_attention_mask),
None,
Some(&target_tensor),
Some(&decoder_attention_mask),
None,
false)
});Generate text based on a vector of promp texts. Read more
Generate token indices without decoding (useful for token-level operations before returning final text or as validation step during training). Read more
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
Generate token indices given a list of indices (useful when the input has been pre-tokenized). Returns a list of output tokens that need to be decoded using a tokenizer. Read more
Returns a reference to the text generator’s tokenizer Read more