[−][src]Struct rust_bert::bart::BartModelOutput
Container holding a BART model output. The decoder output may hold the hidden state of the last layer of the decoder, or may hold logits for a custom head module after the decoder (e.g. for classification or language modeling tasks)
Fields
decoder_output: TensorHidden state of the last layer of the decoder, or logits for a custom head module after the decoder (e.g. for classification or language modeling tasks)
Hidden state for the last layer of the encoder
cache: Option<Vec<(Option<LayerState>, Option<LayerState>)>>Cached outputs of the model (attention layers keys and values) if the model is used for generation
Hidden states for all layers of the decoder
all_decoder_attentions: Option<Vec<Tensor>>Attention weights for all layers of the decoder
Hidden states for all layers of the encoder
all_encoder_attentions: Option<Vec<Tensor>>Attention weights for all layers of the encoder