Struct rust_bert::bert::BertEncoder[][src]

pub struct BertEncoder { /* fields omitted */ }
BERT Encoder

Encoder used in BERT models. It is made of a Vector of BertLayer through which hidden states will be passed. The encoder can also be used as a decoder (with cross-attention) if encoder_hidden_states are provided.

Implementations

Build a new BertEncoder

Arguments
  • p - Variable store path for the root of the BERT model
  • config - BertConfig object defining the model architecture
Example
use rust_bert::bert::{BertConfig, BertEncoder};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = BertConfig::from_file(config_path);
let encoder: BertEncoder = BertEncoder::new(&p.root(), &config);

Forward pass through the encoder

Arguments
  • hidden_states - input tensor of shape (batch size, sequence_length, hidden_size).
  • mask - Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1
  • encoder_hidden_states - Optional encoder hidden state of shape (batch size, encoder_sequence_length, hidden_size). If the model is defined as a decoder and the encoder_hidden_states is not None, used in the cross-attention layer as keys and values (query from the decoder).
  • encoder_mask - Optional encoder attention mask of shape (batch size, encoder_sequence_length). If the model is defined as a decoder and the encoder_hidden_states is not None, used to mask encoder values. Positions with value 0 will be masked.
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • BertEncoderOutput containing:
    • hidden_state - Tensor of shape (batch size, sequence_length, hidden_size)
    • all_hidden_states - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
let encoder: BertEncoder = BertEncoder::new(&vs.root(), &config);
let (batch_size, sequence_length, hidden_size) = (64, 128, 512);
let input_tensor = Tensor::rand(
    &[batch_size, sequence_length, hidden_size],
    (Kind::Float, device),
);
let mask = Tensor::zeros(&[batch_size, sequence_length], (Kind::Int8, device));

let encoder_output =
    no_grad(|| encoder.forward_t(&input_tensor, Some(&mask), None, None, false));