Struct rust_bert::bert::BertForTokenClassification[][src]

pub struct BertForTokenClassification { /* fields omitted */ }
BERT for token classification (e.g. NER, POS)

Token-level classifier predicting a label for each token provided. Note that because of wordpiece tokenization, the labels predicted are not necessarily aligned with words in the sentence. It is made of the following blocks:

  • bert: Base BertModel
  • classifier: Linear layer for token classification

Implementations

Build a new BertForTokenClassification

Arguments
  • p - Variable store path for the root of the BertForTokenClassification model
  • config - BertConfig object defining the model architecture, number of output labels and label mapping
Example
use rust_bert::bert::{BertConfig, BertForTokenClassification};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = BertConfig::from_file(config_path);
let bert = BertForTokenClassification::new(&p.root() / "bert", &config);

Forward pass through the model

Arguments
  • input_ids - Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (see input_embeds)
  • mask - Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1
  • token_type_ids -Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.
  • position_ids - Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.
  • input_embeds - Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (see input_ids)
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • BertTokenClassificationOutput containing:
    • logits - Tensor of shape (batch size, sequence_length, num_labels) containing the logits for each of the input tokens and classes
    • all_hidden_states - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
    .expand(&[batch_size, sequence_length], true);

let model_output = no_grad(|| {
    bert_model.forward_t(
        Some(&input_tensor),
        Some(&mask),
        Some(&token_type_ids),
        Some(&position_ids),
        None,
        false,
    )
});