Struct rust_bert::bert::BertQuestionAnsweringOutput [−][src]
pub struct BertQuestionAnsweringOutput {
pub start_logits: Tensor,
pub end_logits: Tensor,
pub all_hidden_states: Option<Vec<Tensor>>,
pub all_attentions: Option<Vec<Tensor>>,
}Expand description
Container for the BERT question answering model output.
Fields
start_logits: TensorLogits for the start position for token of each input sequence
end_logits: TensorLogits for the end position for token of each input sequence
Hidden states for all intermediate layers
all_attentions: Option<Vec<Tensor>>Attention weights for all intermediate layers