Struct rust_bert::distilbert::DistilBertForTokenClassification[][src]

pub struct DistilBertForTokenClassification { /* fields omitted */ }
DistilBERT for token classification (e.g. NER, POS)

Token-level classifier predicting a label for each token provided. Note that because of wordpiece tokenization, the labels predicted are not necessarily aligned with words in the sentence. It is made of the following blocks:

  • distil_bert_model: Base DistilBertModel
  • classifier: Linear layer for token classification

Implementations

Build a new DistilBertForTokenClassification for sequence classification

Arguments
  • p - Variable store path for the root of the DistilBertForTokenClassification model
  • config - DistilBertConfig object defining the model architecture
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertForTokenClassification};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = DistilBertConfig::from_file(config_path);
let distil_bert = DistilBertForTokenClassification::new(&p.root() / "distilbert", &config);

Forward pass through the model

Arguments
  • input_ids - Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (see input_embeds)
  • mask - Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1
  • input_embeds - Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (see input_ids)
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • DistilBertTokenClassificationOutput containing:
    • logits - Tensor of shape (batch size, sequence_length, num_labels) containing the logits for each of the input tokens and classes
    • all_hidden_states - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertForTokenClassification};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));

let model_output = no_grad(|| {
    distilbert_model
        .forward_t(Some(&input_tensor), Some(&mask), None, false)
        .unwrap()
});