Struct rust_bert::distilbert::DistilBertModelClassifier [−][src]
pub struct DistilBertModelClassifier { /* fields omitted */ }Expand description
DistilBERT for sequence classification
Base DistilBERT model with a pre-classifier and classifier heads to perform sentence or document-level classification It is made of the following blocks:
distil_bert_model: Base DistilBertModelpre_classifier: DistilBERT linear layer for classificationclassifier: DistilBERT linear layer for classification
Implementations
pub fn new<'p, P>(p: P, config: &DistilBertConfig) -> DistilBertModelClassifier where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &DistilBertConfig) -> DistilBertModelClassifier where
P: Borrow<Path<'p>>,
Build a new DistilBertModelClassifier for sequence classification
Arguments
p- Variable store path for the root of the DistilBertModelClassifier modelconfig-DistilBertConfigobject defining the model architecture
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertModelClassifier};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = DistilBertConfig::from_file(config_path);
let distil_bert: DistilBertModelClassifier =
DistilBertModelClassifier::new(&p.root() / "distilbert", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
DistilBertSequenceClassificationOutputcontaining:logits-Tensorof shape (batch size, num_labels)all_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertModelClassifier};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let model_output = no_grad(|| {
distilbert_model
.forward_t(Some(&input_tensor),
Some(&mask),
None,
false).unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for DistilBertModelClassifier
impl Send for DistilBertModelClassifier
impl !Sync for DistilBertModelClassifier
impl Unpin for DistilBertModelClassifier
impl UnwindSafe for DistilBertModelClassifier