Struct rust_bert::distilbert::DistilBertModelMaskedLM[][src]

pub struct DistilBertModelMaskedLM { /* fields omitted */ }
DistilBERT for masked language model

Base DistilBERT model with a masked language model head to predict missing tokens, for example "Looks like one [MASK] is missing" -> "person" It is made of the following blocks:

  • distil_bert_model: Base DistilBertModel
  • vocab_transform:linear layer for classification of size (hidden_dim, hidden_dim)
  • vocab_layer_norm: layer normalization
  • vocab_projector: linear layer for classification of size (hidden_dim, vocab_size) with weights tied to the token embeddings

Implementations

Build a new DistilBertModelMaskedLM for sequence classification

Arguments
  • p - Variable store path for the root of the DistilBertModelMaskedLM model
  • config - DistilBertConfig object defining the model architecture
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertModelMaskedLM};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = DistilBertConfig::from_file(config_path);
let distil_bert = DistilBertModelMaskedLM::new(&p.root() / "distilbert", &config);

Forward pass through the model

Arguments
  • input_ids - Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (see input_embeds)
  • mask - Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1
  • input_embeds - Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (see input_ids)
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • DistilBertMaskedLMOutput containing:
    • prediction_scores - Tensor of shape (batch size, sequence_length, vocab_size)
    • all_hidden_states - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertModelMaskedLM};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));

let model_output = no_grad(|| {
    distilbert_model
        .forward_t(Some(&input_tensor), Some(&mask), None, false)
        .unwrap()
});