Struct rust_bert::electra::ElectraModel [−][src]
pub struct ElectraModel { /* fields omitted */ }Expand description
Electra Base model
Base architecture for Electra models. It is made of the following blocks:
embeddings:token,positionandsegment_idembeddings. Note that in contrast to BERT, the embeddings dimension is not necessarily equal to the hidden layer dimensionsencoder: BertEncoder (transformer) made of a vector of layers. Each layer is made of a self-attention layer, an intermediate (linear) and output (linear + layer norm) layersembeddings_project: (optional) linear layer applied to project the embeddings space to the hidden layer dimension
Implementations
Defines the implementation of the ElectraModel.
Build a new ElectraModel
Arguments
p- Variable store path for the root of the Electra modelconfig-ElectraConfigobject defining the model architecture
Example
use rust_bert::electra::{ElectraConfig, ElectraModel};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = ElectraConfig::from_file(config_path);
let electra_model: ElectraModel = ElectraModel::new(&p.root() / "electra", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
ElectraModelOutputcontaining:hidden_state-Tensorof shape (batch size, sequence_length, hidden_size)all_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[batch_size, sequence_length], true);
let model_output = no_grad(|| {
electra_model
.forward_t(
Some(&input_tensor),
Some(&mask),
Some(&token_type_ids),
Some(&position_ids),
None,
false,
)
.unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for ElectraModel
impl Send for ElectraModel
impl !Sync for ElectraModel
impl Unpin for ElectraModel
impl UnwindSafe for ElectraModel