Struct rust_bert::fnet::FNetForSequenceClassification [−][src]
pub struct FNetForSequenceClassification { /* fields omitted */ }Expand description
FNet for sequence classification
Base FNet model with a classifier head to perform sentence or document-level classification It is made of the following blocks:
fnet: Base FNet modeldropout: Dropout layer before the last linear layerclassifier: linear layer mapping from hidden to the number of classes to predict
Implementations
pub fn new<'p, P>(p: P, config: &FNetConfig) -> FNetForSequenceClassification where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &FNetConfig) -> FNetForSequenceClassification where
P: Borrow<Path<'p>>,
Build a new FNetForSequenceClassification
Arguments
p- Variable store path for the root of the FNet modelconfig-FNetConfigobject defining the model architecture
Example
use rust_bert::fnet::{FNetConfig, FNetForSequenceClassification};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = FNetConfig::from_file(config_path);
let fnet = FNetForSequenceClassification::new(&p.root() / "fnet", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
FNetSequenceClassificationOutputcontaining:logits-Tensorof shape (batch size, num_classes)all_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::fnet::{FNetConfig, FNetForSequenceClassification};
let model = FNetForSequenceClassification::new(&vs.root(), &config);
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[batch_size, sequence_length], true);
let model_output = no_grad(|| {
model
.forward_t(
Some(&input_tensor),
Some(&token_type_ids),
Some(&position_ids),
None,
false,
)
.unwrap()
});Auto Trait Implementations
impl Send for FNetForSequenceClassification
impl !Sync for FNetForSequenceClassification
impl Unpin for FNetForSequenceClassification
impl UnwindSafe for FNetForSequenceClassification