Struct rust_bert::fnet::FNetQuestionAnsweringOutput [−][src]
pub struct FNetQuestionAnsweringOutput {
pub start_logits: Tensor,
pub end_logits: Tensor,
pub all_hidden_states: Option<Vec<Tensor>>,
}Expand description
Container for the FNet question answering model output.
Fields
start_logits: TensorLogits for the start position for token of each input sequence
end_logits: TensorLogits for the end position for token of each input sequence
Hidden states for all intermediate layers