[−][src]Trait rust_bert::gpt2::LMHeadModel
Language Model trait
Shared trait between language generation models (e.g. GPT2 and GPT) used in language generation pipelines.
Required methods
fn forward_t(
&self,
input_ids: &Option<Tensor>,
layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>
&self,
input_ids: &Option<Tensor>,
layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>
Forward pass through the model. Example provided for GPT2.
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)layer_past- Optional vector of size n_layer containing the past keys and values of each layer of shape (2, batch size, number of heads, past_sequence_length, hidden size per head). When provided, these are concatenated with the current input keys and values.attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)token_type_ids- Optional token type ids used to indicate the portion of the input the token belongs to. If not None, token type embeddings will be added to the token and position embeddings.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented starting from the length of the past input.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
output-Tensorof shape (batch size, sequence_length, vocab_size) representing the logits for each vocab item and positionpast-Option<Vec<Tensor>>of length n_layer containing the past keys and values of each layer of shape (2, batch size, number of heads, past_sequence_length, hidden size per head)hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::gpt2::{Gpt2Model, Gpt2Config}; let (batch_size, sequence_length, past_sequence_length) = (64, 128, 56); let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device)); let mut past: Vec<Tensor> = Vec::with_capacity(config.n_layer as usize); for _ in 0..config.n_layer as usize { past.push(Tensor::rand(&[2, batch_size, config.n_head, past_sequence_length, config.n_embd / config.n_head], (Double, device))) } let attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device)); let token_type_ids = Tensor::ones(&[batch_size, sequence_length], (Int64, device)); let position_ids = Tensor::arange(sequence_length, (Int64, device)).expand(&[batch_size, sequence_length], true); let (output, past, hidden_states, attentions) = no_grad(|| { gpt2_model .forward_t(&Some(input_tensor), &Some(past), &Some(attention_mask), &Some(token_type_ids), &Some(position_ids), &None, false).unwrap() });
Implementors
impl LMHeadModel for OpenAIGPTLMHeadModel[src]
fn forward_t(
&self,
input_ids: &Option<Tensor>,
_layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>[src]
&self,
input_ids: &Option<Tensor>,
_layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)token_type_ids- Optional token type ids used to indicate the portion of the input the token belongs to. If not None, token type embeddings will be added to the token and position embeddings.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented starting from the length of the past input.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
output-Tensorof shape (batch size, sequence_length, vocab_size) representing the logits for each vocab item and positionhidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::gpt2::Gpt2Config; use rust_bert::openai_gpt::OpenAiGptModel; let (batch_size, sequence_length, past_sequence_length) = (64, 128, 56); let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device)); let attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device)); let token_type_ids = Tensor::ones(&[batch_size, sequence_length], (Int64, device)); let position_ids = Tensor::arange(sequence_length, (Int64, device)).expand(&[batch_size, sequence_length], true); let (output, hidden_states, attentions) = no_grad(|| { gpt_model .forward_t(&Some(input_tensor), &Some(attention_mask), &Some(token_type_ids), &Some(position_ids), &None, false).unwrap() });
impl LMHeadModel for GPT2LMHeadModel[src]
fn forward_t(
&self,
input_ids: &Option<Tensor>,
layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>[src]
&self,
input_ids: &Option<Tensor>,
layer_past: &Option<Vec<Tensor>>,
attention_mask: &Option<Tensor>,
token_type_ids: &Option<Tensor>,
position_ids: &Option<Tensor>,
input_embeds: &Option<Tensor>,
train: bool
) -> Result<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>), &'static str>
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)layer_past- Optional vector of size n_layer containing the past keys and values of each layer of shape (2, batch size, number of heads, past_sequence_length, hidden size per head). When provided, these are concatenated with the current input keys and values.attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)token_type_ids- Optional token type ids used to indicate the portion of the input the token belongs to. If not None, token type embeddings will be added to the token and position embeddings.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented starting from the length of the past input.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
output-Tensorof shape (batch size, sequence_length, vocab_size) representing the logits for each vocab item and positionpast-Option<Vec<Tensor>>of length n_layer containing the past keys and values of each layer of shape (2, batch size, number of heads, past_sequence_length, hidden size per head)hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::gpt2::{Gpt2Model, Gpt2Config}; let (batch_size, sequence_length, past_sequence_length) = (64, 128, 56); let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device)); let mut past: Vec<Tensor> = Vec::with_capacity(config.n_layer as usize); for _ in 0..config.n_layer as usize { past.push(Tensor::rand(&[2, batch_size, config.n_head, past_sequence_length, config.n_embd / config.n_head], (Double, device))) } let attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device)); let token_type_ids = Tensor::ones(&[batch_size, sequence_length], (Int64, device)); let position_ids = Tensor::arange(sequence_length, (Int64, device)).expand(&[batch_size, sequence_length], true); let (output, past, hidden_states, attentions) = no_grad(|| { gpt2_model .forward_t(&Some(input_tensor), &Some(past), &Some(attention_mask), &Some(token_type_ids), &Some(position_ids), &None, false).unwrap() });