Struct rust_bert::longformer::LongformerForMultipleChoice [−][src]
pub struct LongformerForMultipleChoice { /* fields omitted */ }Expand description
Longformer for multiple choices
Multiple choices model using a Longformer base model and a linear classifier.
Input should be in the form <cls> Context <sep><sep> Possible choice <sep>. The choice is made along the batch axis,
assuming all elements of the batch are alternatives to be chosen from for a given context.
It is made of the following blocks:
longformer: Base LongformerModel modelclassifier: Linear layer for multiple choices
Implementations
pub fn new<'p, P>(
p: P,
config: &LongformerConfig
) -> LongformerForMultipleChoice where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &LongformerConfig
) -> LongformerForMultipleChoice where
P: Borrow<Path<'p>>,
Build a new LongformerForMultipleChoice
Arguments
p- Variable store path for the root of the Longformer modelconfig-LongformerConfigobject defining the model architecture
Example
use rust_bert::longformer::{LongformerConfig, LongformerForMultipleChoice};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = LongformerConfig::from_file(config_path);
let longformer_model = LongformerForMultipleChoice::new(&p.root(), &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). This orinput_embedsmust be provided.attention_mask- Optional attention mask of shape (batch size, sequence_length). Positions with a mask with value 0 will be masked.global_attention_mask- Optional attention mask of shape (batch size, sequence_length). Positions with a mask with value 1 will attend all other positions in the sequence.token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
LongformerSequenceClassificationOutputcontaining:logits-Tensorof shape (1, batch size) containing the logits for each of the alternatives givenall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, num_heads, sequence_length, * attention_window_size*, x + attention_window_size + 1) where x is the number of tokens with global attentionall_global_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, num_heads, sequence_length, attention_window_size, x) where x is the number of tokens with global attention
Example
use rust_bert::longformer::{LongformerConfig, LongformerForMultipleChoice};
let longformer_model = LongformerForMultipleChoice::new(&vs.root(), &config);
let (batch_size, sequence_length, target_sequence_length) = (64, 128, 32);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let global_attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let target_tensor = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let model_output = no_grad(|| {
longformer_model
.forward_t(
Some(&input_tensor),
Some(&attention_mask),
Some(&global_attention_mask),
None,
None,
None,
false,
)
.unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for LongformerForMultipleChoice
impl Send for LongformerForMultipleChoice
impl !Sync for LongformerForMultipleChoice
impl Unpin for LongformerForMultipleChoice
impl UnwindSafe for LongformerForMultipleChoice