Struct rust_bert::m2m_100::M2M100Model [−][src]
pub struct M2M100Model { /* fields omitted */ }Expand description
M2M100 Base model
Base architecture for M2M100 model. Usually complemented with a task-specific head, such as a language model head. It is made of the following blocks:
encoder:M2M100Encoder(transformer) made of a vector of encoding layersdecoder:M2M100Decoder(transformer) made of a vector of decoding layers with self attention and encoder cross-attention. caching is implemented for the decoder to avoid recalculating static states (encoder key/values and previously calculated decoder key/values)pad_token_id: padding token id
Implementations
Build a new M2M100Model
Arguments
p- Variable store path for the root of the M2M100 modelconfig-M2M100Configobject defining the model architecture
Example
use rust_bert::m2m_100::{M2M100Config, M2M100Model};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = M2M100Config::from_file(config_path);
let m2m100: M2M100Model = M2M100Model::new(&p.root() / "m2m100", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, source_sequence_length). Must be provided when not running in generation modeattention_mask- Optional attention mask of shape (batch size, source_sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). Must be provided when running in generation mode (e.g. initialized with a BOS token)encoder_outputs- Optional tuple made of a tensor of shape (batch size, source_sequence_length, encoder_hidden_dim) and optional vectors of tensors of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size). These correspond to the encoder last hidden state and optional hidden states/attention weights for encoder layers. When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.decoder_attention_mask- Optional attention mask of shape (batch size, target_sequence_length) for the decoder positions. Positions with a mask with value 0 will be masked.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
M2M100ModelOutputcontaining:decoder_output-Tensorof shape (batch size, target_sequence_length, hidden_size) representing the activations of the last decoder hidden stateencoder_hidden_states-Option<Tensor>of shape (batch size, source_sequence_length, hidden_size) representing the activations of the last encoder hidden state if it was not provided, otherwise Nonecache-(Option<Tensor>, Option<Vec<&LayerState, &LayerState>>)of length n_layer containing the encoder padding mask and past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.all_encoder_hidden_states-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_encoder_attentions-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_decoder_hidden_states-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)all_decoder_attentions-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)
Example
use rust_bert::m2m_100::{M2M100Config, M2M100Model};
let (batch_size, source_sequence_length, target_sequence_length) = (64, 128, 56);
let input_tensor = Tensor::rand(&[batch_size, source_sequence_length], (Int64, device));
let target_tensor = Tensor::rand(&[batch_size, target_sequence_length], (Int64, device));
let encoder_attention_mask =
Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let decoder_attention_mask =
Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let model_output = no_grad(|| {
m2m100_model.forward_t(
Some(&input_tensor),
Some(&encoder_attention_mask),
Some(&target_tensor),
None,
Some(&decoder_attention_mask),
None,
false,
)
});Auto Trait Implementations
impl RefUnwindSafe for M2M100Model
impl Send for M2M100Model
impl !Sync for M2M100Model
impl Unpin for M2M100Model
impl UnwindSafe for M2M100Model