Struct rust_bert::marian::MarianGenerator [−][src]
pub struct MarianGenerator { /* fields omitted */ }Expand description
Implementations
Build a new marianGenerator
Arguments
vocab_path- Path to the model vocabulary, expected to have a structure following the Transformers library conventionsentencepiece_model_path- Path to the sentencepiece model (native protobuf expected)config_path- Path to the model configuration, expected to have a structure following the Transformers library conventionweights_path- Path to the model weight files. These need to be converted form the.binto.otformat using the utility script provided.device- Device to run the model on, e.g.Device::CpuorDevice::Cuda(0)
Example
use rust_bert::marian::MarianGenerator;
use rust_bert::pipelines::generation_utils::GenerateConfig;
let device = Device::cuda_if_available();
let generate_config = GenerateConfig {
max_length: 512,
do_sample: true,
num_beams: 6,
temperature: 1.0,
num_return_sequences: 1,
..Default::default()
};
let marian_generator = MarianGenerator::new(generate_config)?;Trait Implementations
Generate text based on a vector of promp texts. Read more
Generate token indices without decoding (useful for token-level operations before returning final text or as validation step during training). Read more
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
Generate token indices given a list of indices (useful when the input has been pre-tokenized). Returns a list of output tokens that need to be decoded using a tokenizer. Read more
Returns a reference to the text generator’s tokenizer Read more