Struct rust_bert::mobilebert::MobileBertForMaskedLM [−][src]
pub struct MobileBertForMaskedLM { /* fields omitted */ }Expand description
MobileBERT for masked language model
Base MobileBERT model with a masked language model head to predict missing tokens, for example "Looks like one [MASK] is missing" -> "person"
It is made of the following blocks:
mobilebert: Base MobileBertModelclassifier: MobileBERT LM prediction head
Implementations
pub fn new<'p, P>(p: P, config: &MobileBertConfig) -> MobileBertForMaskedLM where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &MobileBertConfig) -> MobileBertForMaskedLM where
P: Borrow<Path<'p>>,
Build a new MobileBertForMaskedLM
Arguments
p- Variable store path for the root of the MobileBERT modelconfig-MobileBertConfigobject defining the model architecture and decoder status
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertForMaskedLM};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = MobileBertConfig::from_file(config_path);
let mobilebert = MobileBertForMaskedLM::new(&p.root(), &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
MobileBertMaskedLMOutputcontaining:logits-Tensorof shape (batch size, sequence_length, vocab_size)all_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertForMaskedLM};
let model = MobileBertForMaskedLM::new(&vs.root(), &config);
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[batch_size, sequence_length], true);
let model_output = no_grad(|| {
model
.forward_t(
Some(&input_tensor),
Some(&token_type_ids),
Some(&position_ids),
None,
Some(&attention_mask),
false,
)
.unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for MobileBertForMaskedLM
impl Send for MobileBertForMaskedLM
impl !Sync for MobileBertForMaskedLM
impl Unpin for MobileBertForMaskedLM
impl UnwindSafe for MobileBertForMaskedLM