Struct rust_bert::mobilebert::MobileBertForMultipleChoice [−][src]
pub struct MobileBertForMultipleChoice { /* fields omitted */ }Expand description
MobileBERT for multiple choices
Multiple choices model using a MobileBERT base model and a linear classifier.
Input should be in the form [CLS] Context [SEP] Possible choice [SEP]. The choice is made along the batch axis,
assuming all elements of the batch are alternatives to be chosen from for a given context.
It is made of the following blocks:
mobilebert: Base MobileBertModeldropout: Dropout layer before the last start/end logits predictionclassifier: Linear layer for multiple choices
Implementations
pub fn new<'p, P>(
p: P,
config: &MobileBertConfig
) -> MobileBertForMultipleChoice where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &MobileBertConfig
) -> MobileBertForMultipleChoice where
P: Borrow<Path<'p>>,
Build a new MobileBertForMultipleChoice
Arguments
p- Variable store path for the root of the MobileBERT modelconfig-MobileBertConfigobject defining the model architecture and decoder status
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertForMultipleChoice};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = MobileBertConfig::from_file(config_path);
let mobilebert = MobileBertForMultipleChoice::new(&p.root(), &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
MobileBertSequenceClassificationOutputcontaining:logits-Tensorof shape (1, batch_size) containing the logits for each of the alternatives givenall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertForMultipleChoice};
let model = MobileBertForMultipleChoice::new(&vs.root(), &config);
let (batch_size, sequence_length) = (64, 128);
let (num_choices, sequence_length) = (3, 128);
let input_tensor = Tensor::rand(&[num_choices, sequence_length], (Int64, device));
let attention_mask = Tensor::zeros(&[num_choices, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[num_choices, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[num_choices, sequence_length], true);
let model_output = no_grad(|| {
model
.forward_t(
Some(&input_tensor),
Some(&token_type_ids),
Some(&position_ids),
None,
Some(&attention_mask),
false,
)
.unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for MobileBertForMultipleChoice
impl Send for MobileBertForMultipleChoice
impl !Sync for MobileBertForMultipleChoice
impl Unpin for MobileBertForMultipleChoice
impl UnwindSafe for MobileBertForMultipleChoice