Struct rust_bert::mobilebert::MobileBertModel [−][src]
pub struct MobileBertModel { /* fields omitted */ }Expand description
MobileBertModel Base model
Base architecture for MobileBERT models. Task-specific models will be built from this common base model It is made of the following blocks:
embeddings: Word, token type and position embeddingsencoder:MobileBertEncodermade of a stack ofMobileBertLayerpooler: OptionalMobileBertPoolertaking the first sequence element hidden state for sequence-level tasksposition_idspreset position ids tensor used in case they are not provided by the user
Implementations
pub fn new<'p, P>(
p: P,
config: &MobileBertConfig,
add_pooling_layer: bool
) -> MobileBertModel where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &MobileBertConfig,
add_pooling_layer: bool
) -> MobileBertModel where
P: Borrow<Path<'p>>,
Build a new MobileBertModel
Arguments
p- Variable store path for the root of the MobileBERT modelconfig-MobileBertConfigobject defining the model architecture and decoder statusadd_poling_layer- boolean flag indicating if a pooling layer should be added after the encoder
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertModel};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = MobileBertConfig::from_file(config_path);
let add_pooling_layer = true;
let mobilebert = MobileBertModel::new(&p.root() / "mobilebert", &config, add_pooling_layer);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)token_type_ids- Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. SEP) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)attention_mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
MobileBertOutputcontaining:hidden_state-Tensorof shape (batch size, sequence_length, hidden_size)pooled_output- OptionalTensorof shape (batch size, hidden_size) if the model was created with an optional pooling layerall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::mobilebert::{MobileBertConfig, MobileBertModel};
let add_pooling_layer = true;
let model = MobileBertModel::new(&vs.root(), &config, add_pooling_layer);
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[batch_size, sequence_length], true);
let model_output = no_grad(|| {
model
.forward_t(
Some(&input_tensor),
Some(&token_type_ids),
Some(&position_ids),
None,
Some(&attention_mask),
false,
)
.unwrap()
});Auto Trait Implementations
impl RefUnwindSafe for MobileBertModel
impl Send for MobileBertModel
impl !Sync for MobileBertModel
impl Unpin for MobileBertModel
impl UnwindSafe for MobileBertModel