Struct rust_bert::openai_gpt::OpenAiGptModelOutput [−][src]
pub struct OpenAiGptModelOutput {
pub hidden_state: Tensor,
pub all_hidden_states: Option<Vec<Tensor>>,
pub all_attentions: Option<Vec<Tensor>>,
}Expand description
Container for the OpenAI GPT model output.
Fields
Hidden state of the last layer of the decoder, or logits for a custom head module after the decoder (e.g. vocabulary logits for language modeling tasks)
Hidden states for all intermediate layers
all_attentions: Option<Vec<Tensor>>Attention weights for all intermediate layers