[][src]Struct rust_bert::pipelines::generation::OpenAIGenerator

pub struct OpenAIGenerator { /* fields omitted */ }

Methods

impl OpenAIGenerator[src]

pub fn new(
    vocab_path: &Path,
    merges_path: &Path,
    config_path: &Path,
    weight_path: &Path,
    generate_config: GenerateConfig,
    device: Device
) -> Fallible<OpenAIGenerator>
[src]

Build a new OpenAIGenerator

Arguments

  • vocab_path - Path to the model vocabulary, expected to have a structure following the Transformers library convention
  • merges_path - Path to the bpe merges, expected to have a structure following the Transformers library convention
  • config_path - Path to the model configuration, expected to have a structure following the Transformers library convention
  • weights_path - Path to the model weight files. These need to be converted form the .bin to .ot format using the utility script provided.
  • device - Device to run the model on, e.g. Device::Cpu or Device::Cuda(0)

Example

use rust_bert::pipelines::generation::{GenerateConfig, OpenAIGenerator};
let device = Device::cuda_if_available();
let generate_config = GenerateConfig {
   max_length: 30,
   do_sample: true,
   num_beams: 5,
   temperature: 1.1,
   num_return_sequences: 3,
   ..Default::default()
};
let gpt_generator = OpenAIGenerator::new(vocab_path, merges_path, config_path, weights_path,
                                         generate_config, device)?;