[−][src]Struct rust_bert::pipelines::generation_utils::MarianGenerator
Implementations
impl MarianGenerator[src]
pub fn new(
generate_config: GenerateConfig
) -> Result<MarianGenerator, RustBertError>[src]
generate_config: GenerateConfig
) -> Result<MarianGenerator, RustBertError>
Build a new marianGenerator
Arguments
vocab_path- Path to the model vocabulary, expected to have a structure following the Transformers library conventionsentencepiece_model_path- Path to the sentencepiece model (native protobuf expected)config_path- Path to the model configuration, expected to have a structure following the Transformers library conventionweights_path- Path to the model weight files. These need to be converted form the.binto.otformat using the utility script provided.device- Device to run the model on, e.g.Device::CpuorDevice::Cuda(0)
Example
use rust_bert::pipelines::generation_utils::{GenerateConfig, MarianGenerator}; let device = Device::cuda_if_available(); let generate_config = GenerateConfig { max_length: 512, do_sample: true, num_beams: 6, temperature: 1.0, num_return_sequences: 1, ..Default::default() }; let marian_generator = MarianGenerator::new(generate_config)?;