Struct rust_bert::pipelines::sentiment::SentimentModel[][src]

pub struct SentimentModel { /* fields omitted */ }
Implementations

Build a new SentimentModel

Arguments
  • sentiment_config - SentimentConfig object containing the resource references (model, vocabulary, configuration) and device placement (CPU/GPU)
Example
use rust_bert::pipelines::sentiment::SentimentModel;

let sentiment_model = SentimentModel::new(Default::default())?;

Extract sentiment form an array of text inputs

Arguments
  • input - &[&str] Array of texts to extract the sentiment from.
Returns
  • Vec<Sentiment> Sentiments extracted from texts.
Example
use rust_bert::pipelines::sentiment::SentimentModel;

let sentiment_classifier =  SentimentModel::new(Default::default())?;

let input = [
    "Probably my all-time favorite movie, a story of selflessness, sacrifice and dedication to a noble cause, but it's not preachy or boring.",
    "This film tried to be too many things all at once: stinging political satire, Hollywood blockbuster, sappy romantic comedy, family values promo...",
    "If you like original gut wrenching laughter you will like this movie. If you are young or old then you will love this movie, hell even my mom liked it.",
];

let output = sentiment_classifier.predict(&input);