[−][src]Enum rust_bert::pipelines::sequence_classification::SequenceClassificationOption
Abstraction that holds one particular sequence classification model, for any of the supported models
Variants
Bert for Sequence Classification
DistilBert(DistilBertModelClassifier)DistilBert for Sequence Classification
Roberta(RobertaForSequenceClassification)Roberta for Sequence Classification
XLMRoberta(RobertaForSequenceClassification)XLMRoberta for Sequence Classification
Albert(AlbertForSequenceClassification)Albert for Sequence Classification
XLNet for Sequence Classification
Bart for Sequence Classification
Implementations
impl SequenceClassificationOption[src]
pub fn new<'p, P>(
model_type: ModelType,
p: P,
config: &ConfigOption
) -> Result<Self, RustBertError> where
P: Borrow<Path<'p>>, [src]
model_type: ModelType,
p: P,
config: &ConfigOption
) -> Result<Self, RustBertError> where
P: Borrow<Path<'p>>,
Instantiate a new sequence classification model of the supplied type.
Arguments
model_type-ModelTypeindicating the model type to load (must match with the actual data to be loaded)p-tch::nn::Pathpath to the model file to load (e.g. model.ot)config- A configuration (the model type of the configuration must be compatible with the value formodel_type)
pub fn model_type(&self) -> ModelType[src]
Returns the ModelType for this SequenceClassificationOption
pub fn forward_t(
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
token_type_ids: Option<Tensor>,
position_ids: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> Tensor[src]
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
token_type_ids: Option<Tensor>,
position_ids: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> Tensor
Interface method to forward_t() of the particular models.