Enum rust_bert::pipelines::token_classification::TokenClassificationOption[][src]

Variants

Bert(BertForTokenClassification)

Bert for Token Classification

DistilBert(DistilBertForTokenClassification)

DistilBert for Token Classification

MobileBert(MobileBertForTokenClassification)

MobileBert for Token Classification

Roberta(RobertaForTokenClassification)

Roberta for Token Classification

XLMRoberta(RobertaForTokenClassification)

XLM Roberta for Token Classification

Electra(ElectraForTokenClassification)

Electra for Token Classification

Albert(AlbertForTokenClassification)

Albert for Token Classification

XLNet(XLNetForTokenClassification)

XLNet for Token Classification

Longformer(LongformerForTokenClassification)

Longformer for Token Classification

FNet(FNetForTokenClassification)

FNet for Token Classification

Implementations

Instantiate a new token sequence classification model of the supplied type.

Arguments
  • model_type - ModelType indicating the model type to load (must match with the actual data to be loaded)
  • p - tch::nn::Path path to the model file to load (e.g. model.ot)
  • config - A configuration (the model type of the configuration must be compatible with the value for model_type)

Returns the ModelType for this TokenClassificationOption