Struct rust_bert::prophetnet::ProphetNetModel [−][src]
pub struct ProphetNetModel { /* fields omitted */ }Expand description
ProphetNet Base model
Base architecture for ProphetNet models. Task-specific models will be built from this common base model It is made of the following blocks:
word_embeddings: Word embeddingsencoder: ProphetNetEncoderdecoder: ProphetNetDecoder
Implementations
pub fn new<'p, P>(
p: P,
config: &ProphetNetConfig
) -> Result<ProphetNetModel, RustBertError> where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &ProphetNetConfig
) -> Result<ProphetNetModel, RustBertError> where
P: Borrow<Path<'p>>,
Build a new ProphetNetModel
Arguments
p- Variable store path for the root of the ProphetNet modelconfig-ProphetNetConfigobject defining the model architecture
Example
use rust_bert::prophetnet::{ProphetNetConfig, ProphetNetModel};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = ProphetNetConfig::from_file(config_path);
let prophetnet_model = ProphetNetModel::new(&p.root(), &config);pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
input_embeds: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
encoder_hidden_states: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
decoder_input_embeds: Option<&Tensor>,
train: bool
) -> Result<ProphetNetOutput, RustBertError>
pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
input_embeds: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
encoder_hidden_states: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
decoder_input_embeds: Option<&Tensor>,
train: bool
) -> Result<ProphetNetOutput, RustBertError>
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). This orinput_embedsmust be provided.attention_mask- Optional attention mask of shape (batch size, sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.input_embeds- Optional input tensor of shape (batch size, sequence_length, embeddings dimension). This orinput_idsmust be provided.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). Must be provided when running in generation mode (e.g. initialized with a BOS token)decoder_attention_mask- Optional attention mask of shape (batch size, target_sequence_length) for the decoder positions. Positions with a mask with value 0 will be masked.encoder_hidden_states- Optional tensor of shape (batch size, source_sequence_length, encoder_hidden_dim) corresponding to pre-calculated encoder hidden states (useful for conditional generation) These correspond to the encoder last hidden state and optional hidden states/attention weights for encoder layers. When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.old_layer_states- Optional VectorOption<Vec<Option<&LayerState>, Option<&LayerState>>>of length n_layer containing tuples with the past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.decoder_input_embeds- Optional input tensor of shape (batch size, target_sequence_length, embeddings dimension). This ordecoder_input_idsmust be provided.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
ProphetNetOutputcontaining:last_hidden_states-Tensorof shape (batch size, target_sequence_length, hidden_size) representing the activations of the last hidden state for the decoderngram_hidden_states-Tensorof shape (ngram, batch size, target_sequence_length, hidden_size) representing the activations of the last hidden state for the decoder ngram streamnext_decoder_cache-Option<Vec<Option<LayerState>>>of length n_layer containing the past content for the the attention layers with shape (past_sequence_length, batch size, hidden_size)all_decoder_hidden_states-Option<Vec<Tensor>>of length n_layer with shape (batch size, target_sequence_length, hidden_size)all_ngram_decoder_hidden_states-Option<Vec<Tensor>>of length n_layer with shape (ngram, batch size, target_sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length n_layer with shape (batch size, target_sequence_length, hidden_size)all_ngram_attentions-Option<Vec<Tensor>>of length n_layer with shape (ngram, batch size, target_sequence_length, hidden_size)all_cross_attentions-Option<Vec<Tensor>>of length n_layer with shape (batch size, target_sequence_length, hidden_size)
Example
use rust_bert::prophetnet::{ProphetNetModel, ProphetNetConfig};
let (batch_size, sequence_length, target_sequence_length) = (64, 128, 32);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_tensor = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let decoder_input_ids = Tensor::ones(&[batch_size, target_sequence_length], (Kind::Float, device));
let model_output = no_grad(|| {
prophetnet_model.forward_t(
Some(&input_tensor),
Some(&attention_mask),
None,
Some(&decoder_input_ids),
None,
None,
None,
None,
false
)
});Auto Trait Implementations
impl RefUnwindSafe for ProphetNetModel
impl Send for ProphetNetModel
impl !Sync for ProphetNetModel
impl Unpin for ProphetNetModel
impl UnwindSafe for ProphetNetModel