Struct rust_bert::reformer::ReformerForSequenceClassification[][src]

pub struct ReformerForSequenceClassification { /* fields omitted */ }
Reformer Model for sequence classification

Reformer model with a classification head It is made of the following blocks:

  • reformer: ReformerModel Base Reformer model
  • classifier: ReformerClassificationHead projecting hidden states to the target labels

Implementations

Build a new ReformerForSequenceClassification

Arguments
  • p - Variable store path for the root of the BART model
  • config - ReformerConfig object defining the model architecture
Example
use rust_bert::reformer::{ReformerConfig, ReformerForSequenceClassification};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = ReformerConfig::from_file(config_path);
let reformer_model: ReformerForSequenceClassification =
    ReformerForSequenceClassification::new(&p.root(), &config).unwrap();

Forward pass through the model

Arguments
  • input_ids - Optional input tensor of shape (batch size, sequence_length). Must be provided when no pre-computed embeddings are given.
  • position_ids - Optional input tensor of shape (batch size, sequence_length). If not provided will be calculated on the fly starting from position 0.
  • input_embeds - Optional input tensor of shape (batch size, sequence_length, embeddings_dim). Must be provided when no input ids are given.
  • attention_mask - Optional attention mask of shape (batch size, sequence_length). Positions with a mask with value 0 will be masked.
  • num_hashes - Optional specification of the number of hashes to use. If not provided will use the value provided in the model configuration.
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • ReformerClassificationOutput containing:
    • logits - Tensor of shape (batch size, sequence_length, num_classes) representing the logits for each target class
    • all_hidden_states - Option<Vec<Tensor>> of length n_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length n_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::reformer::{ReformerConfig, ReformerForSequenceClassification};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let input_positions = Tensor::arange(sequence_length, (Kind::Int64, device)).unsqueeze(0).expand(&[batch_size, sequence_length], true);
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));

let model_output = no_grad(|| {
    reformer_model.forward_t(
        Some(&input_tensor),
        Some(&input_positions),
        None,
        Some(&attention_mask),
        Some(4),
        false,
    )
});