Struct rust_bert::resources::RemoteResource[][src]

pub struct RemoteResource {
    pub url: String,
    pub cache_subdir: String,
}
Fields

url: String

Remote path/url for the resource

cache_subdir: String

Local subdirectory of the cache root where this resource is saved

Implementations

Creates a new RemoteResource from an URL and a custom local path. Note that this does not download the resource (only declares the remote and local locations)

Arguments
  • url - &str Location of the remote resource
  • cache_subdir - &str Local subdirectory of the cache root to save the resource to
Returns
  • RemoteResource RemoteResource object
Example
use rust_bert::resources::{RemoteResource, Resource};
let config_resource = Resource::Remote(RemoteResource::new(
    "configs",
    "http://config_json_location",
));

Creates a new RemoteResource from an URL and local name. Will define a local path pointing to ~/.cache/.rustbert/model_name. Note that this does not download the resource (only declares the remote and local locations)

Arguments
  • name_url_tuple - (&str, &str) Location of the name of model and remote resource
Returns
  • RemoteResource RemoteResource object
Example
use rust_bert::resources::{RemoteResource, Resource};
let model_resource = Resource::Remote(RemoteResource::from_pretrained((
    "distilbert-sst2",
    "https://huggingface.co/distilbert-base-uncased-finetuned-sst-2-english/resolve/main/rust_model.ot",
)));