Struct rust_bert::roberta::RobertaForMultipleChoice [−][src]
pub struct RobertaForMultipleChoice { /* fields omitted */ }Expand description
RoBERTa for multiple choices
Multiple choices model using a RoBERTa base model and a linear classifier.
Input should be in the form <s> Context </s> Possible choice </s>. The choice is made along the batch axis,
assuming all elements of the batch are alternatives to be chosen from for a given context.
It is made of the following blocks:
roberta: Base RoBERTa modelclassifier: Linear layer for multiple choices
Implementations
pub fn new<'p, P>(p: P, config: &BertConfig) -> RobertaForMultipleChoice where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &BertConfig) -> RobertaForMultipleChoice where
P: Borrow<Path<'p>>,
Build a new RobertaForMultipleChoice
Arguments
p- Variable store path for the root of the RobertaForMultipleChoice modelconfig-BertConfigobject defining the model architecture and vocab size
Example
use rust_bert::bert::BertConfig;
use rust_bert::roberta::RobertaForMultipleChoice;
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = BertConfig::from_file(config_path);
let roberta = RobertaForMultipleChoice::new(&p.root() / "roberta", &config);Forward pass through the model
Arguments
input_ids- Input tensor of shape (batch size, sequence_length).mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1token_type_ids-Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. ) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
RobertaSequenceClassificationOutputcontaining:logits-Tensorof shape (1, batch size) containing the logits for each of the alternatives givenall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::roberta::RobertaForMultipleChoice;
let (num_choices, sequence_length) = (3, 128);
let input_tensor = Tensor::rand(&[num_choices, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[num_choices, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[num_choices, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[num_choices, sequence_length], true);
let model_output = no_grad(|| {
roberta_model.forward_t(
&input_tensor,
Some(&mask),
Some(&token_type_ids),
Some(&position_ids),
false,
)
});Auto Trait Implementations
impl RefUnwindSafe for RobertaForMultipleChoice
impl Send for RobertaForMultipleChoice
impl !Sync for RobertaForMultipleChoice
impl Unpin for RobertaForMultipleChoice
impl UnwindSafe for RobertaForMultipleChoice