Struct rust_bert::roberta::RobertaForQuestionAnswering [−][src]
pub struct RobertaForQuestionAnswering { /* fields omitted */ }Expand description
RoBERTa for question answering
Extractive question-answering model based on a RoBERTa language model. Identifies the segment of a context that answers a provided question. Please note that a significant amount of pre- and post-processing is required to perform end-to-end question answering. See the question answering pipeline (also provided in this crate) for more details. It is made of the following blocks:
roberta: Base RoBERTa modelqa_outputs: Linear layer for question answering
Implementations
pub fn new<'p, P>(p: P, config: &BertConfig) -> RobertaForQuestionAnswering where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(p: P, config: &BertConfig) -> RobertaForQuestionAnswering where
P: Borrow<Path<'p>>,
Build a new RobertaForQuestionAnswering
Arguments
p- Variable store path for the root of the RobertaForQuestionAnswering modelconfig-BertConfigobject defining the model architecture and vocab size
Example
use rust_bert::bert::BertConfig;
use rust_bert::roberta::RobertaForQuestionAnswering;
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = BertConfig::from_file(config_path);
let roberta = RobertaForQuestionAnswering::new(&p.root() / "roberta", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1token_type_ids-Optional segment id of shape (batch size, sequence_length). Convention is value of 0 for the first sentence (incl. ) and 1 for the second sentence. If None set to 0.position_ids- Optional position ids of shape (batch size, sequence_length). If None, will be incremented from 0.input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
RobertaQuestionAnsweringOutputcontaining:start_logits-Tensorof shape (batch size, sequence_length) containing the logits for start of the answerend_logits-Tensorof shape (batch size, sequence_length) containing the logits for end of the answerall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Vec<Tensor>>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::roberta::RobertaForQuestionAnswering;
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let token_type_ids = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let position_ids = Tensor::arange(sequence_length, (Int64, device))
.expand(&[batch_size, sequence_length], true);
let model_output = no_grad(|| {
roberta_model.forward_t(
Some(&input_tensor),
Some(&mask),
Some(&token_type_ids),
Some(&position_ids),
None,
false,
)
});Auto Trait Implementations
impl RefUnwindSafe for RobertaForQuestionAnswering
impl Send for RobertaForQuestionAnswering
impl !Sync for RobertaForQuestionAnswering
impl Unpin for RobertaForQuestionAnswering
impl UnwindSafe for RobertaForQuestionAnswering