[−][src]Struct rust_bert::t5::T5ForConditionalGeneration
T5 Model for conditional generation
T5 model with a vocabulary decoding head It is made of the following blocks:
base_model:T5ModelBase T5 modelmodel_dim:f64representation of the model dimension for scaling of the generated logits
Implementations
impl T5ForConditionalGeneration[src]
pub fn new<'p, P>(
p: P,
config: &T5Config,
output_attentions: bool,
output_hidden_states: bool
) -> T5ForConditionalGeneration where
P: Borrow<Path<'p>>, [src]
p: P,
config: &T5Config,
output_attentions: bool,
output_hidden_states: bool
) -> T5ForConditionalGeneration where
P: Borrow<Path<'p>>,
Build a new T5ForConditionalGeneration
Arguments
p- Variable store path for the root of the BART modelconfig-T5Configobject defining the model architectureoutput_attention- flag indicating if the model should output the attention weights of intermediate layersoutput_hidden_states- flag indicating if the model should output the hidden states weights of intermediate layers
Example
use rust_bert::t5::{T5Config, T5ForConditionalGeneration}; use rust_bert::Config; use std::path::Path; use tch::{nn, Device}; let config_path = Path::new("path/to/config.json"); let device = Device::Cpu; let p = nn::VarStore::new(device); let config = T5Config::from_file(config_path); let output_attentions = true; let output_hidden_states = true; let t5 = T5ForConditionalGeneration::new( &p.root() / "t5", &config, output_attentions, output_hidden_states, );
pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_outputs: Option<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>)>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
input_embeds: Option<Tensor>,
decoder_input_embeds: Option<Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> (Tensor, Tensor, Option<Vec<(Option<LayerState>, Option<LayerState>)>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>)[src]
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_outputs: Option<(Tensor, Option<Vec<Tensor>>, Option<Vec<Tensor>>)>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
input_embeds: Option<Tensor>,
decoder_input_embeds: Option<Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> (Tensor, Tensor, Option<Vec<(Option<LayerState>, Option<LayerState>)>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>, Option<Vec<Tensor>>)
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, source_sequence_length). This orinput_embedsmust be provided.attention_mask- Optional attention mask of shape (batch size, source_sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). This ordecoder_input_embedsmust be provided.encoder_outputs- Optional tuple made of a tensor of shape (batch size, source_sequence_length, encoder_hidden_dim) and optional vectors of tensors of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size). These correspond to the encoder last hidden state and optional hidden states/attention weights for encoder layers. When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.decoder_attention_mask- Optional attention mask of shape (batch size, target_sequence_length) for the decoder positions. Positions with a mask with value 0 will be masked.input_embeds- Optional input tensor of shape (batch size, source_sequence_length, embeddings dimension). This orinput_idsmust be provided.decoder_input_embeds- Optional input tensor of shape (batch size, target_sequence_length, embeddings dimension). This ordecoder_input_idsmust be provided.old_layer_states- Optional vector of lengthnum_layerscontaining tuples of optionalLayerStatescontaining th elast calculated key and value pairs for the decoder. This avoids recomputing attention weights at past positions and speeds up decoding.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
decoder_output-Tensorof shape (batch size, target_sequence_length, hidden_size) representing the activations of the last decoder hidden stateencoder_hidden_states-Tensorof shape (batch size, source_sequence_length, hidden_size) representing the activations of the last encoder hidden statedecoder_cache-Option<Vec<(Option<Vec<&LayerState, &LayerState>>)>>of length n_layer containing the encoder past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.all_encoder_hidden_states-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_encoder_attentions-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_decoder_hidden_states-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)all_decoder_attentions-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)
Example
use rust_bert::t5::{T5Config, T5ForConditionalGeneration}; let (batch_size, source_sequence_length, target_sequence_length) = (64, 128, 56); let input_tensor = Tensor::rand(&[batch_size, source_sequence_length], (Int64, device)); let target_tensor = Tensor::rand(&[batch_size, target_sequence_length], (Int64, device)); let encoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device)); let decoder_attention_mask = Tensor::ones(&[batch_size, source_sequence_length], (Int64, device)); let ( decoder_output, encoder_hidden_states, decoder_cache, all_encoder_hidden_states, all_encoder_attentions, all_decoder_hidden_states, all_decoder_attentions, ) = no_grad(|| { t5_model.forward_t( Some(&input_tensor), Some(&encoder_attention_mask), None, Some(&target_tensor), Some(&decoder_attention_mask), None, None, None, false, ) });
pub fn encode(
&self,
input_ids: &Tensor,
attention_mask: Option<&Tensor>
) -> Tensor[src]
&self,
input_ids: &Tensor,
attention_mask: Option<&Tensor>
) -> Tensor