Struct rust_bert::t5::T5Model [−][src]
pub struct T5Model { /* fields omitted */ }Expand description
T5 Base model
Base architecture for T5 model. Usually complemented with a task-specific head, such as a language model head. It is made of the following blocks:
encoder:T5Stack(transformer) made of a vector of encoding layersdecoder:T5Stack(transformer) made of a vector of decoding layers with self attention and encoder cross-attention. caching is implemented for the decoder to avoid recalculating static states (encoder key/values and previously calculated decoder key/values)embeddings:nn::EmbeddingShared embeddings for the encoder and decoder.
Implementations
Build a new T5Model
Arguments
p- Variable store path for the root of the BART modelconfig-T5Configobject defining the model architectureoutput_attention- flag indicating if the model should output the attention weights of intermediate layersoutput_hidden_states- flag indicating if the model should output the hidden states weights of intermediate layers
Example
use rust_bert::t5::{T5Config, T5Model};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = T5Config::from_file(config_path);
let output_attentions = true;
let output_hidden_states = true;
let t5: T5Model = T5Model::new(
&p.root() / "t5",
&config,
output_attentions,
output_hidden_states,
);pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_outputs: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
input_embeds: Option<&Tensor>,
decoder_input_embeds: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> T5ModelOutput
pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
encoder_outputs: Option<&Tensor>,
decoder_input_ids: Option<&Tensor>,
decoder_attention_mask: Option<&Tensor>,
input_embeds: Option<&Tensor>,
decoder_input_embeds: Option<&Tensor>,
old_layer_states: Option<Vec<(Option<LayerState>, Option<LayerState>)>>,
train: bool
) -> T5ModelOutput
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, source_sequence_length). This orinput_embedsmust be provided.attention_mask- Optional attention mask of shape (batch size, source_sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.decoder_input_ids- Optional input tensor of shape (batch size, target_sequence_length). This ordecoder_input_embedsmust be provided.encoder_outputs- Optional tuple made of a tensor of shape (batch size, source_sequence_length, encoder_hidden_dim) and optional vectors of tensors of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size). These correspond to the encoder last hidden state and optional hidden states/attention weights for encoder layers. When provided, the encoder hidden state will not be recalculated. Useful for generation tasks.decoder_attention_mask- Optional attention mask of shape (batch size, target_sequence_length) for the decoder positions. Positions with a mask with value 0 will be masked.input_embeds- Optional input tensor of shape (batch size, source_sequence_length, embeddings dimension). This orinput_idsmust be provided.decoder_input_embeds- Optional input tensor of shape (batch size, target_sequence_length, embeddings dimension). This ordecoder_input_idsmust be provided.old_layer_states- Optional vector of lengthnum_layerscontaining tuples of optionalLayerStatescontaining the last calculated key and value pairs for the decoder. This avoids recomputing attention weights at past positions and speeds up decoding.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
T5ModelOutputcontaining:decoder_output-Tensorof shape (batch size, target_sequence_length, hidden_size) representing the activations of the last decoder hidden stateencoder_hidden_states-Tensorof shape (batch size, source_sequence_length, hidden_size) representing the activations of the last encoder hidden statecache-Option<Vec<(Option<Vec<LayerState, LayerState>>)>>of length n_layer containing the encoder padding mask and past keys and values for both the self attention and the encoder cross attention of each layer of the decoder.all_encoder_hidden_states-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_encoder_attentions-Option<Vec<Tensor>>of length num_encoder_layers with shape (batch size, source_sequence_length, hidden_size)all_decoder_hidden_states-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)all_decoder_attentions-Option<Vec<Tensor>>of length num_decoder_layers with shape (batch size, target_sequence_length, hidden_size)
Example
use rust_bert::t5::{T5Config, T5Model};
let (batch_size, source_sequence_length, target_sequence_length) = (64, 128, 56);
let input_tensor = Tensor::rand(&[batch_size, source_sequence_length], (Int64, device));
let target_tensor = Tensor::rand(&[batch_size, target_sequence_length], (Int64, device));
let encoder_attention_mask =
Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let decoder_attention_mask =
Tensor::ones(&[batch_size, source_sequence_length], (Int64, device));
let model_output = no_grad(|| {
t5_model.forward_t(
Some(&input_tensor),
Some(&encoder_attention_mask),
None,
Some(&target_tensor),
Some(&decoder_attention_mask),
None,
None,
None,
false,
)
});Auto Trait Implementations
impl RefUnwindSafe for T5Model
impl UnwindSafe for T5Model