Struct rust_bert::xlnet::XLNetForMultipleChoice [−][src]
pub struct XLNetForMultipleChoice { /* fields omitted */ }Expand description
XLNetForMultipleChoice
Multiple choices model using a XLNet base model and a linear classifier.
Input should be in the form [CLS] Context [SEP] Possible choice [SEP]. The choice is made along the batch axis,
assuming all elements of the batch are alternatives to be chosen from for a given context.
It is made of the following blocks:
base_model:XLNetModelsequence_summary:SequenceSummaryto pool the base model hidden stateslogits_proj: Linear layer projecting the hidden layer pooled output to a single value
Implementations
pub fn new<'p, P>(
p: P,
config: &XLNetConfig
) -> Result<XLNetForMultipleChoice, RustBertError> where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &XLNetConfig
) -> Result<XLNetForMultipleChoice, RustBertError> where
P: Borrow<Path<'p>>,
Build a new XLNetForMultipleChoice
Arguments
p- Variable store path for the root of the XLNet modelconfig-XLNetConfigobject defining the model architecture
Example
use rust_bert::xlnet::{XLNetConfig, XLNetForMultipleChoice};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = XLNetConfig::from_file(config_path);
let xlnet_model = XLNetForMultipleChoice::new(&p.root(), &config);pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
old_layer_states: Option<Vec<Option<LayerState>>>,
perm_mask: Option<&Tensor>,
target_mapping: Option<&Tensor>,
token_type_ids: Option<&Tensor>,
input_embeds: Option<&Tensor>,
train: bool
) -> XLNetSequenceClassificationOutput
pub fn forward_t(
&self,
input_ids: Option<&Tensor>,
attention_mask: Option<&Tensor>,
old_layer_states: Option<Vec<Option<LayerState>>>,
perm_mask: Option<&Tensor>,
target_mapping: Option<&Tensor>,
token_type_ids: Option<&Tensor>,
input_embeds: Option<&Tensor>,
train: bool
) -> XLNetSequenceClassificationOutput
Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). This orinput_embedsmust be provided.attention_mask- Optional attention mask of shape (batch size, sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.perm_mask- Optional tensor of shape (batch size, sequence_length, sequence_length). Mask to indicate the attention pattern for each input token (only used for pre-training over permutations, rather than simple token masking).target_mapping- Optional tensor of shape (batch size, num_tokens, sequence_length) indicating the position of the masked words to predict.token_type_ids- Optional tensor (batch size, sequence_length) indicating the sentence ID of the token (0: first sentence, 1: second sentence).input_embeds- Optional input tensor of shape (batch size, sequence_length, embeddings dimension). This orinput_idsmust be provided.old_layer_states- Optional vector of lengthnum_layerscontaining optionalLayerStatescontaining the last calculated content for the attention layers. This avoids recomputing attention weights at past positions and speeds up decoding.train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
XLNetSequenceClassificationOutputcontaining:logits-Tensorof shape (1, batch size) containing the logits for each of the alternatives givennext_cache-Option<Vec<Option<LayerState>>>of length n_layer containing the past content for the the attention layers with shape (past_sequence_length, batch size, hidden_size)all_hidden_states-Option<Vec<(Tensor, Option<Tensor>)>>of length n_layer with shape (batch size, sequence_length, hidden_size) (with optional query stream states if used)all_attentions-Option<Vec<(Tensor, Option<Tensor>)>>of length n_layer with shape (batch size, sequence_length, hidden_size) (with optional query stream states if used)
Example
use rust_bert::xlnet::{XLNetConfig, XLNetForMultipleChoice};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_tensor = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_mapping = Tensor::zeros(&[64, 1, 128], (Kind::Float, device));
let _ = target_mapping.narrow(2, 3, 1).fill_(1.0);
let model_output = no_grad(|| {
xlnet_model.forward_t(
Some(&input_tensor),
Some(&attention_mask),
None,
Some(&target_mapping),
None,
None,
None,
false
)
});Auto Trait Implementations
impl RefUnwindSafe for XLNetForMultipleChoice
impl Send for XLNetForMultipleChoice
impl !Sync for XLNetForMultipleChoice
impl Unpin for XLNetForMultipleChoice
impl UnwindSafe for XLNetForMultipleChoice