Struct rust_bert::xlnet::XLNetForSequenceClassification[][src]

pub struct XLNetForSequenceClassification { /* fields omitted */ }
XLNetForSequenceClassification

XLNet model with a classification head for sequence classification tasks It is made of the following blocks:

  • base_model: XLNetModel
  • sequence_summary: SequenceSummary to pool the base model hidden states
  • logits_proj: Linear layer projecting the hidden layer pooled output to the target space

Implementations

Build a new XLNetForSequenceClassification

Arguments
  • p - Variable store path for the root of the XLNet model
  • config - XLNetConfig object defining the model architecture
Example
use rust_bert::xlnet::{XLNetConfig, XLNetForSequenceClassification};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = XLNetConfig::from_file(config_path);
let xlnet_model = XLNetForSequenceClassification::new(&p.root(), &config);

Forward pass through the model

Arguments
  • input_ids - Optional input tensor of shape (batch size, sequence_length). This or input_embeds must be provided.
  • attention_mask - Optional attention mask of shape (batch size, sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.
  • perm_mask - Optional tensor of shape (batch size, sequence_length, sequence_length). Mask to indicate the attention pattern for each input token (only used for pre-training over permutations, rather than simple token masking).
  • target_mapping - Optional tensor of shape (batch size, num_tokens, sequence_length) indicating the position of the masked words to predict.
  • token_type_ids - Optional tensor (batch size, sequence_length) indicating the sentence ID of the token (0: first sentence, 1: second sentence).
  • input_embeds - Optional input tensor of shape (batch size, sequence_length, embeddings dimension). This or input_ids must be provided.
  • old_layer_states - Optional vector of length num_layers containing optional LayerStates containing the last calculated content for the attention layers. This avoids recomputing attention weights at past positions and speeds up decoding.
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
  • XLNetSequenceClassificationOutput containing:
    • logits - Tensor of shape (batch size, num_classes) representing the logits for each batch item and class
    • next_cache - Option<Vec<Option<LayerState>>> of length n_layer containing the past content for the the attention layers with shape (past_sequence_length, batch size, hidden_size)
    • all_hidden_states - Option<Vec<(Tensor, Option<Tensor>)>> of length n_layer with shape (batch size, sequence_length, hidden_size) (with optional query stream states if used)
    • all_attentions - Option<Vec<(Tensor, Option<Tensor>)>> of length n_layer with shape (batch size, sequence_length, hidden_size) (with optional query stream states if used)
Example
use rust_bert::xlnet::{XLNetConfig, XLNetForSequenceClassification};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_tensor = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_mapping = Tensor::zeros(&[64, 1, 128], (Kind::Float, device));
let _ = target_mapping.narrow(2, 3, 1).fill_(1.0);

let model_output = no_grad(|| {
    xlnet_model.forward_t(
        Some(&input_tensor),
        Some(&attention_mask),
        None,
        Some(&target_mapping),
        None,
        None,
        None,
        false
    )
});