Struct rust_bert::xlnet::XLNetGenerator [−][src]
pub struct XLNetGenerator { /* fields omitted */ }Expand description
Implementations
Build a new XLNetGenerator
Arguments
generate_config-GenerateConfigobject containing the resource references (model, vocabulary, configuration), generation options and device placement (CPU/GPU)
Example
use rust_bert::pipelines::generation_utils::GenerateConfig;
use rust_bert::xlnet::XLNetGenerator;
let generate_config = GenerateConfig {
max_length: 30,
do_sample: true,
num_beams: 5,
temperature: 1.1,
num_return_sequences: 3,
..Default::default()
};
let xlnet_generator = XLNetGenerator::new(generate_config)?;Trait Implementations
Generate text based on a vector of promp texts. Read more
Generate token indices without decoding (useful for token-level operations before returning final text or as validation step during training). Read more
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
fn generate_from_ids_and_past(
&self,
input_ids: Tensor,
attention_mask: Option<Tensor>,
generate_options: Option<GenerateOptions<'_>>
) -> Vec<GeneratedIndicesOutput>ⓘ
Generate token indices given a list of indices (useful when the input has been pre-tokenized). Returns a list of output tokens that need to be decoded using a tokenizer. Read more
Returns a reference to the text generator’s tokenizer Read more