[−][src]Struct rust_bert::bert::BertQuestionAnsweringOutput
Container for the BERT question answering model output.
Fields
start_logits: TensorLogits for the start position for token of each input sequence
end_logits: TensorLogits for the end position for token of each input sequence
Hidden states for all intermediate layers
all_attentions: Option<Vec<Tensor>>Attention weights for all intermediate layers