Struct rust_bert::distilbert::DistilBertForQuestionAnswering [−][src]
pub struct DistilBertForQuestionAnswering { /* fields omitted */ }Expand description
DistilBERT for question answering
Extractive question-answering model based on a DistilBERT language model. Identifies the segment of a context that answers a provided question. Please note that a significant amount of pre- and post-processing is required to perform end-to-end question answering. See the question answering pipeline (also provided in this crate) for more details. It is made of the following blocks:
distil_bert_model: Base DistilBertModelqa_outputs: Linear layer for question answering
Implementations
pub fn new<'p, P>(
p: P,
config: &DistilBertConfig
) -> DistilBertForQuestionAnswering where
P: Borrow<Path<'p>>,
pub fn new<'p, P>(
p: P,
config: &DistilBertConfig
) -> DistilBertForQuestionAnswering where
P: Borrow<Path<'p>>,
Build a new DistilBertForQuestionAnswering for sequence classification
Arguments
p- Variable store path for the root of the DistilBertForQuestionAnswering modelconfig-DistilBertConfigobject defining the model architecture
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertForQuestionAnswering};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};
let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = DistilBertConfig::from_file(config_path);
let distil_bert = DistilBertForQuestionAnswering::new(&p.root() / "distilbert", &config);Forward pass through the model
Arguments
input_ids- Optional input tensor of shape (batch size, sequence_length). If None, pre-computed embeddings must be provided (seeinput_embeds)mask- Optional mask of shape (batch size, sequence_length). Masked position have value 0, non-masked value 1. If None set to 1input_embeds- Optional pre-computed input embeddings of shape (batch size, sequence_length, hidden_size). If None, input ids must be provided (seeinput_ids)train- boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.
Returns
DistilBertQuestionAnsweringOutputcontaining:start_logits-Tensorof shape (batch size, sequence_length) containing the logits for start of the answerend_logits-Tensorof shape (batch size, sequence_length) containing the logits for end of the answerall_hidden_states-Option<Vec<Tensor>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)all_attentions-Option<Vec<Vec<Tensor>>>of length num_hidden_layers with shape (batch size, sequence_length, hidden_size)
Example
use rust_bert::distilbert::{DistilBertConfig, DistilBertForQuestionAnswering};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let mask = Tensor::zeros(&[batch_size, sequence_length], (Int64, device));
let model_output = no_grad(|| {
distilbert_model
.forward_t(Some(&input_tensor), Some(&mask), None, false)
.unwrap()
});Auto Trait Implementations
impl Send for DistilBertForQuestionAnswering
impl !Sync for DistilBertForQuestionAnswering
impl Unpin for DistilBertForQuestionAnswering
impl UnwindSafe for DistilBertForQuestionAnswering