Struct rust_bert::gpt2::Gpt2ModelOutput [−][src]
pub struct Gpt2ModelOutput {
pub output: Tensor,
pub cache: Option<Vec<Tensor>>,
pub all_hidden_states: Option<Vec<Tensor>>,
pub all_attentions: Option<Vec<Tensor>>,
}Expand description
Container for the GPT2 model output.
Fields
output: TensorHidden state of the last layer of the decoder, or logits for a custom head module after the decoder (e.g. vocabulary logits for language modeling tasks)
cache: Option<Vec<Tensor>>Cached attention layers keys and values if the model is used for generation
Hidden states for all intermediate layers
all_attentions: Option<Vec<Tensor>>Attention weights for all intermediate layers