[−][src]Struct rust_bert::pipelines::ner::NERModel
Methods
impl NERModel[src]
pub fn new(
vocab_path: &Path,
config_path: &Path,
weights_path: &Path,
device: Device
) -> Fallible<NERModel>[src]
vocab_path: &Path,
config_path: &Path,
weights_path: &Path,
device: Device
) -> Fallible<NERModel>
Build a new NERModel
Arguments
vocab_path- Path to the model vocabulary, expected to have a structure following the Transformers library conventionconfig_path- Path to the model configuration, expected to have a structure following the Transformers library conventionweights_path- Path to the model weight files. These need to be converted form the.binto.otformat using the utility script provided.device- Device to run the model on, e.g.Device::CpuorDevice::Cuda(0)
Example
use tch::Device; use std::path::{Path, PathBuf}; use rust_bert::pipelines::ner::NERModel; let mut home: PathBuf = dirs::home_dir().unwrap(); let config_path = &home.as_path().join("config.json"); let vocab_path = &home.as_path().join("vocab.txt"); let weights_path = &home.as_path().join("model.ot"); let device = Device::Cpu; let ner_model = NERModel::new(vocab_path, config_path, weights_path, device)?;
pub fn predict(&self, input: &[&str]) -> Vec<Entity>[src]
Extract entities from a text
Arguments
input-&[&str]Array of texts to extract entities from.
Returns
Vec<Entity>containing extracted entities
Example
let ner_model = NERModel::new(vocab_path, config_path, weights_path, device)?; let input = [ "My name is Amy. I live in Paris.", "Paris is a city in France." ]; let output = ner_model.predict(&input);