[−][src]Enum rust_bert::pipelines::question_answering::QuestionAnsweringOption
Variants
Bert(BertForQuestionAnswering)Bert for Question Answering
DistilBert(DistilBertForQuestionAnswering)DistilBert for Question Answering
Roberta(RobertaForQuestionAnswering)Roberta for Question Answering
XLMRoberta(RobertaForQuestionAnswering)XLMRoberta for Question Answering
Albert(AlbertForQuestionAnswering)Albert for Question Answering
Implementations
impl QuestionAnsweringOption[src]
pub fn new<'p, P>(model_type: ModelType, p: P, config: &ConfigOption) -> Self where
P: Borrow<Path<'p>>, [src]
P: Borrow<Path<'p>>,
Instantiate a new question answering model of the supplied type.
Arguments
model_type-ModelTypeindicating the model type to load (must match with the actual data to be loaded)p-tch::nn::Pathpath to the model file to load (e.g. model.ot)config- A configuration (the model type of the configuration must be compatible with the value formodel_type)
pub fn model_type(&self) -> ModelType[src]
Returns the ModelType for this SequenceClassificationOption
pub fn forward_t(
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> (Tensor, Tensor)[src]
&self,
input_ids: Option<Tensor>,
mask: Option<Tensor>,
input_embeds: Option<Tensor>,
train: bool
) -> (Tensor, Tensor)
Interface method to forward_t() of the particular models.