[][src]Struct rust_bert::pipelines::question_answering::QuestionAnsweringConfig

pub struct QuestionAnsweringConfig {
    pub model_resource: Resource,
    pub config_resource: Resource,
    pub vocab_resource: Resource,
    pub merges_resource: Option<Resource>,
    pub device: Device,
    pub model_type: ModelType,
    pub lower_case: bool,
}

Configuration for question answering

Contains information regarding the model to load and device to place the model on.

Fields

model_resource: Resource

Model weights resource (default: pretrained DistilBERT model on SQuAD)

config_resource: Resource

Config resource (default: pretrained DistilBERT model on SQuAD)

vocab_resource: Resource

Vocab resource (default: pretrained DistilBERT model on SQuAD)

merges_resource: Option<Resource>

Merges resource (default: None)

device: Device

Device to place the model on (default: CUDA/GPU when available)

model_type: ModelType

Model type

lower_case: bool

Flag indicating if the model expects a lower casing of the input

Implementations

impl QuestionAnsweringConfig[src]

pub fn new(
    model_type: ModelType,
    model_resource: Resource,
    config_resource: Resource,
    vocab_resource: Resource,
    merges_resource: Option<Resource>,
    lower_case: bool
) -> QuestionAnsweringConfig
[src]

Instantiate a new question answering configuration of the supplied type.

Arguments

  • model_type - ModelType indicating the model type to load (must match with the actual data to be loaded!)
  • model_resource - The Resource pointing to the model to load (e.g. model.ot)
  • config_resource - The `Resource' pointing to the model configuration to load (e.g. config.json)
  • vocab_resource - The `Resource' pointing to the tokenizer's vocabulary to load (e.g. vocab.txt/vocab.json)
  • merges_resource - An optional Resource tuple (Option<Resource>) pointing to the tokenizer's merge file to load (e.g. merges.txt), needed only for Roberta.
  • lower_case - A `bool' indicating whether the tokeniser should lower case all input (in case of a lower-cased model)