[−][src]Enum rust_bert::pipelines::token_classification::LabelAggregationOption
Enum defining the label aggregation method for sub tokens
Defines the behaviour for labels aggregation if the consolidation of sub-tokens is enabled.
Variants
The label of the first sub token is assigned to the entire token
The label of the last sub token is assigned to the entire token
The most frequent sub- token is assigned to the entire token
The user can provide a function mapping a &Vec<Token> to a (i64, String) tuple corresponding to the label index, label String to return