[−][src]Enum rust_bert::pipelines::token_classification::TokenClassificationOption
Variants
Bert for Token Classification
DistilBert(DistilBertForTokenClassification)DistilBert for Token Classification
MobileBert(MobileBertForTokenClassification)MobileBert for Token Classification
Roberta(RobertaForTokenClassification)Roberta for Token Classification
XLMRoberta(RobertaForTokenClassification)XLM Roberta for Token Classification
Electra(ElectraForTokenClassification)Electra for Token Classification
Albert(AlbertForTokenClassification)Albert for Token Classification
XLNet(XLNetForTokenClassification)XLNet for Token Classification
Implementations
impl TokenClassificationOption[src]
pub fn new<'p, P>(
model_type: ModelType,
p: P,
config: &ConfigOption
) -> Result<Self, RustBertError> where
P: Borrow<Path<'p>>, [src]
model_type: ModelType,
p: P,
config: &ConfigOption
) -> Result<Self, RustBertError> where
P: Borrow<Path<'p>>,
Instantiate a new token sequence classification model of the supplied type.
Arguments
model_type-ModelTypeindicating the model type to load (must match with the actual data to be loaded)p-tch::nn::Pathpath to the model file to load (e.g. model.ot)config- A configuration (the model type of the configuration must be compatible with the value formodel_type)
pub fn model_type(&self) -> ModelType[src]
Returns the ModelType for this TokenClassificationOption