Struct rust_bert::resources::CACHE [−][src]
pub struct CACHE { /* fields omitted */ }Expand description
Global cache directory
If the environment variable RUSTBERT_CACHE is set, will save the cache model files at that
location. Otherwise defaults to ~/.cache/.rustbert.
Methods from Deref<Target = Cache>
Get the cached path to a resource.
If the resource is local file, it’s path is returned. If the resource is a static HTTP resource, it will cached locally and the path to the cache file will be returned.
Get the cached path to a resource using the given options.
Examples
Use a particular subdirectory of the cache root:
let path = cache.cached_path_with_options(
resource,
&Options::default().subdir(subdir),
).unwrap();Treat the resource as an archive and extract it. The path returned is the path to the extraction directory:
let path = cache.cached_path_with_options(
resource,
&Options::default().extract(),
).unwrap();
assert!(path.is_dir());pub fn cached_path_in_subdir(
&self,
resource: &str,
subdir: Option<&str>
) -> Result<PathBuf, Error>
👎 Deprecated since 0.4.4: Please use Cache::cached_path_with_options() instead
pub fn cached_path_in_subdir(
&self,
resource: &str,
subdir: Option<&str>
) -> Result<PathBuf, Error>
Please use Cache::cached_path_with_options() instead
A convenience method to get the cached path to a resource using the given cache subdirectory (relative to the cache root).
This is equivalent to:
let path = cache.cached_path_with_options(
resource,
&Options::default().subdir(subdir),
).unwrap();Trait Implementations