[−][src]Module rust_bert::roberta
RoBERTa: A Robustly Optimized BERT Pretraining Approach (Liu et al.)
Implementation of the RoBERTa language model (https://arxiv.org/abs/1907.11692 Liu, Ott, Goyal, Du, Joshi, Chen, Levy, Lewis, Zettlemoyer, Stoyanov, 2019).
The base model is implemented in the bert::BertModel struct. Several language model heads have also been implemented, including:
- Masked language model:
roberta::RobertaForMaskedLM - Multiple choices:
roberta:RobertaForMultipleChoice - Question answering:
roberta::RobertaForQuestionAnswering - Sequence classification:
roberta::RobertaForSequenceClassification - Token classification (e.g. NER, POS tagging):
roberta::RobertaForTokenClassification
Model set-up and pre-trained weights loading
A full working example is provided in examples/robert.rs, run with cargo run --example roberta.
The example below illustrate a Masked language model example, the structure is similar for other models.
All models expect the following resources:
- Configuration file expected to have a structure following the Transformers library
- Model weights are expected to have a structure and parameter names following the Transformers library. A conversion using the Python utility scripts is required to convert the
.binweights to the.otformat. RobertaTokenizerusing avocab.txtvocabulary andmerges.txt2-gram merges
use rust_tokenizers::RobertaTokenizer; use tch::{nn, Device}; use rust_bert::bert::BertConfig; use rust_bert::Config; use rust_bert::roberta::RobertaForMaskedLM; let device = Device::cuda_if_available(); let mut vs = nn::VarStore::new(device); let tokenizer: RobertaTokenizer = RobertaTokenizer::from_file(vocab_path.to_str().unwrap(), merges_path.to_str().unwrap(), true); let config = BertConfig::from_file(config_path); let bert_model = RobertaForMaskedLM::new(&vs.root(), &config); vs.load(weights_path)?;
Structs
| RobertaEmbeddings | BertEmbeddings implementation for RoBERTa model |
| RobertaForMaskedLM | RoBERTa for masked language model |
| RobertaForMultipleChoice | RoBERTa for multiple choices |
| RobertaForQuestionAnswering | RoBERTa for question answering |
| RobertaForSequenceClassification | RoBERTa for sequence classification |
| RobertaForTokenClassification | RoBERTa for token classification (e.g. NER, POS) |