[][src]Struct rust_bert::xlnet::XLNetLMHeadModel

pub struct XLNetLMHeadModel { /* fields omitted */ }

XLNetLMHeadModel

XLNet model with a language model head for language generation tasks It is made of the following blocks:

  • base_model: XLNetModel
  • lm_head: Linear language modeling head, projecting the hidden state logits to the vocabulary space

Implementations

impl XLNetLMHeadModel[src]

pub fn new<'p, P>(p: P, config: &XLNetConfig) -> XLNetLMHeadModel where
    P: Borrow<Path<'p>>, 
[src]

Build a new XLNetLMHeadModel

Arguments

  • p - Variable store path for the root of the XLNet model
  • config - XLNetConfig object defining the model architecture

Example

use rust_bert::xlnet::{XLNetConfig, XLNetLMHeadModel};
use rust_bert::Config;
use std::path::Path;
use tch::{nn, Device};

let config_path = Path::new("path/to/config.json");
let device = Device::Cpu;
let p = nn::VarStore::new(device);
let config = XLNetConfig::from_file(config_path);
let xlnet_model = XLNetLMHeadModel::new(&p.root(), &config);

pub fn forward_t(
    &self,
    input_ids: Option<&Tensor>,
    attention_mask: Option<&Tensor>,
    old_layer_states: Option<Vec<Option<LayerState>>>,
    perm_mask: Option<&Tensor>,
    target_mapping: Option<&Tensor>,
    token_type_ids: Option<&Tensor>,
    input_embeds: Option<Tensor>,
    train: bool
) -> Result<LMModelOutput, RustBertError>
[src]

Forward pass through the model

Arguments

  • input_ids - Optional input tensor of shape (batch size, sequence_length). This or input_embeds must be provided.
  • attention_mask - Optional attention mask of shape (batch size, sequence_length) for the encoder positions. Positions with a mask with value 0 will be masked.
  • perm_mask - Optional tensor of shape (batch size, sequence_length, sequence_length). Mask to indicate the attention pattern for each input token (only used for pre-training over permutations, rather than simple token masking).
  • target_mapping - Optional tensor of shape (batch size, num_tokens, sequence_length) indicating the position of the masked words to predict.
  • token_type_ids - Optional tensor (batch size, sequence_length) indicating the sentence ID of the token (0: first sentence, 1: second sentence).
  • input_embeds - Optional input tensor of shape (batch size, sequence_length, embeddings dimension). This or input_ids must be provided.
  • old_layer_states - Optional vector of length num_layers containing optional LayerStates containing the last calculated content for the attention layers. This avoids recomputing attention weights at past positions and speeds up decoding.
  • train - boolean flag to turn on/off the dropout layers in the model. Should be set to false for inference.

Returns

  • LMModelOutput containing:
    • lm_logits - Tensor of shape (batch size, sequence_length, vocab_size) representing the logits for each vocab item and position
    • cache - XLNetCache made of Option<Vec<Option<LayerState>>> of length n_layers and shape (past_sequence_length, batch size, hidden_size) containing the previous content
    • encoder_hidden_states - None
    • all_hidden_states - Option<Vec<Tensor>> of length n_layers with shape (batch size, sequence_length, hidden_size)
    • all_attentions - Option<Vec<Tensor>> of length n_layers with shape (batch size, sequence_length, hidden_size)

Example

use rust_bert::xlnet::{XLNetConfig, XLNetLMHeadModel};
let (batch_size, sequence_length) = (64, 128);
let input_tensor = Tensor::rand(&[batch_size, sequence_length], (Int64, device));
let attention_mask = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_tensor = Tensor::ones(&[batch_size, sequence_length], (Int64, device));
let target_mapping = Tensor::zeros(&[64, 1, 128], (Kind::Float, device));
let _ = target_mapping.narrow(2, 3, 1).fill_(1.0);

let model_output = no_grad(|| {
    xlnet_model.forward_t(
        Some(&input_tensor),
        Some(&attention_mask),
        None,
        Some(&target_mapping),
        None,
        None,
        None,
        false,
    )
});